aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTom Lane <tgl@sss.pgh.pa.us>2000-12-03 17:18:10 +0000
committerTom Lane <tgl@sss.pgh.pa.us>2000-12-03 17:18:10 +0000
commit68ed2963011257e566f5f174ef670e01bbdc2b34 (patch)
tree9ff763a4c49e1c4222f08bef3613242c660f8538
parente7c80220d35a47265001159607503cae2a7ac90c (diff)
downloadpostgresql-68ed2963011257e566f5f174ef670e01bbdc2b34.tar.gz
postgresql-68ed2963011257e566f5f174ef670e01bbdc2b34.zip
Don't use 'private' as a parameter name in visible headers ... makes C++
very unhappy ...
-rw-r--r--src/backend/storage/ipc/ipc.c6
-rw-r--r--src/backend/storage/ipc/ipci.c8
-rw-r--r--src/include/storage/ipc.h7
3 files changed, 11 insertions, 10 deletions
diff --git a/src/backend/storage/ipc/ipc.c b/src/backend/storage/ipc/ipc.c
index 7b3dd4b3d50..804411bb960 100644
--- a/src/backend/storage/ipc/ipc.c
+++ b/src/backend/storage/ipc/ipc.c
@@ -8,7 +8,7 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/storage/ipc/ipc.c,v 1.55 2000/11/30 03:11:24 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/storage/ipc/ipc.c,v 1.56 2000/12/03 17:18:10 tgl Exp $
*
* NOTES
*
@@ -663,7 +663,7 @@ IpcInitKeyAssignment(int port)
* but we do not fail upon collision with non-Postgres shmem segments.
*/
PGShmemHeader *
-IpcMemoryCreate(uint32 size, bool private, int permission)
+IpcMemoryCreate(uint32 size, bool makePrivate, int permission)
{
void *memAddress;
PGShmemHeader *hdr;
@@ -677,7 +677,7 @@ IpcMemoryCreate(uint32 size, bool private, int permission)
IpcMemoryId shmid;
/* Special case if creating a private segment --- just malloc() it */
- if (private)
+ if (makePrivate)
{
memAddress = PrivateMemoryCreate(size);
break;
diff --git a/src/include/storage/ipc.h b/src/include/storage/ipc.h
index b633297d5f6..55aa2963587 100644
--- a/src/include/storage/ipc.h
+++ b/src/include/storage/ipc.h
@@ -7,7 +7,7 @@
* Portions Copyright (c) 1996-2000, PostgreSQL, Inc
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $Id: ipc.h,v 1.43 2000/11/28 23:27:57 tgl Exp $
+ * $Id: ipc.h,v 1.44 2000/12/03 17:18:09 tgl Exp $
*
* Some files that would normally need to include only sys/ipc.h must
* instead include this file because on Ultrix, sys/ipc.h is not designed
@@ -104,10 +104,11 @@ extern void IpcSemaphoreUnlock(IpcSemaphoreId semId, int sem);
extern bool IpcSemaphoreTryLock(IpcSemaphoreId semId, int sem);
extern int IpcSemaphoreGetValue(IpcSemaphoreId semId, int sem);
-extern PGShmemHeader *IpcMemoryCreate(uint32 size, bool private,
+extern PGShmemHeader *IpcMemoryCreate(uint32 size, bool makePrivate,
int permission);
/* ipci.c */
-extern void CreateSharedMemoryAndSemaphores(bool private, int maxBackends);
+extern void CreateSharedMemoryAndSemaphores(bool makePrivate,
+ int maxBackends);
#endif /* IPC_H */
diff --git a/src/backend/storage/ipc/ipci.c b/src/backend/storage/ipc/ipci.c
index a813a530bfe..60e4d16cc04 100644
--- a/src/backend/storage/ipc/ipci.c
+++ b/src/backend/storage/ipc/ipci.c
@@ -8,7 +8,7 @@
*
*
* IDENTIFICATION
- * $Header: /cvsroot/pgsql/src/backend/storage/ipc/ipci.c,v 1.36 2000/11/30 01:39:07 tgl Exp $
+ * $Header: /cvsroot/pgsql/src/backend/storage/ipc/ipci.c,v 1.37 2000/12/03 17:18:10 tgl Exp $
*
*-------------------------------------------------------------------------
*/
@@ -33,11 +33,11 @@
* It is NEVER called by a backend forked from the postmaster;
* for such a backend, the shared memory is already ready-to-go.
*
* If "private" is true then we only need private memory, not shared
* memory. This is true for a standalone backend, false for a postmaster.
*/
void
-CreateSharedMemoryAndSemaphores(bool private, int maxBackends)
+CreateSharedMemoryAndSemaphores(bool makePrivate, int maxBackends)
{
int size;
PGShmemHeader *seghdr;
@@ -62,7 +62,7 @@ CreateSharedMemoryAndSemaphores(bool private, int maxBackends)
/*
* Create the shmem segment
*/
- seghdr = IpcMemoryCreate(size, private, IPCProtection);
+ seghdr = IpcMemoryCreate(size, makePrivate, IPCProtection);
/*
* First initialize spinlocks --- needed by InitShmemAllocation()
@@ -33,11 +33,11 @@
* for such a backend, the shared memory is already ready-to-go.
*
- * If "private" is true then we only need private memory, not shared
+ * If "makePrivate" is true then we only need private memory, not shared
* memory. This is true for a standalone backend, false for a postmaster.
*/